@@ -20,6 +20,8 @@
 #' @examples
 #'
 #' # With milestones
+#'
+#' \donttest{
 #' raw_milestones <- gh::gh(
 #'     repo = "jdplus-main",
 #'     owner = "jdemetra",
@@ -29,6 +31,7 @@
 #' )
 #' raw_milestone <- raw_milestones[[5L]]
 #' format_milestone(raw_milestone)
+#' }
 #'
 format_milestone <- function(raw_milestone, verbose = TRUE) {
     if (verbose) {
@@ -65,45 +68,38 @@ get_milestones <- function(
     source <- match.arg(source)
 
     if (source == "online") {
-        milestones <- gh::gh(
-            repo = repo,
-            owner = owner,
-            endpoint = "/repos/:owner/:repo/milestones",
-            state = "all",
-            .limit = Inf
-        ) |>
-            format_milestones(verbose = verbose)
+        raw_milestones <- try(expr = {
+            gh::gh(
+                repo = repo,
+                owner = owner,
+                endpoint = "/repos/:owner/:repo/milestones",
+                state = "all",
+                .limit = Inf
+            )
+        })
+        check_response(raw_milestones)
+        milestones <- format_milestones(raw_milestones, verbose = verbose)
 
         if (nrow(milestones) > 0L) {
             milestones <- cbind(milestones, repo = repo, owner = owner)
         }
     } else if (source == "local") {
-        input_file <- tools::file_path_sans_ext(dataset_name)
+        if (tools::file_ext(dataset_name) == "yaml") {
+            input_file <- tools::file_path_sans_ext(dataset_name)
+        }
         input_path <- file.path(dataset_dir, input_file) |>
-            normalizePath(mustWork = FALSE) |>
-            paste0(".yaml")
+            paste0(".yaml") |>
+            normalizePath(mustWork = TRUE)
 
-        if (file.exists(input_path)) {
-            if (verbose) {
-                message("The milestones will be read from ", input_path, ".")
-            }
-            milestones <- yaml::read_yaml(file = input_path) |>
-                as.data.frame()
-            if (nrow(milestones) > 0L) {
-                milestones[["due_on"]] <- format_timestamp(
-                    x = milestones[["due_on"]]
-                )
-            }
-        } else {
-            stop(
-                "The file ",
-                input_path,
-                " doesn't exist.\n",
-                "Run `write_milestones_to_dataset()`",
-                " to write a set of milestones in the directory\n",
-                "Or call get_milestones() with the argument",
-                " `source` to \"online\".",
-                call. = FALSE
+        if (verbose) {
+            message("The milestones will be read from ", input_path, ".")
+        }
+        milestones <- readLines(con = input_path, encoding = "UTF-8") |>
+            yaml::yaml.load() |>
+            as.data.frame()
+        if (nrow(milestones) > 0L) {
+            milestones[["due_on"]] <- format_timestamp(
+                x = milestones[["due_on"]]
             )
         }
     } else {
@@ -161,10 +157,12 @@ write_milestones_to_dataset <- function(
     dataset_name = "list_milestones.yaml",
     verbose = TRUE
 ) {
-    output_file <- tools::file_path_sans_ext(dataset_name)
+    if (tools::file_ext(dataset_name) == "yaml") {
+        output_file <- tools::file_path_sans_ext(dataset_name)
+    }
     output_path <- file.path(dataset_dir, output_file) |>
-        normalizePath(mustWork = FALSE) |>
-        paste0(".yaml")
+        paste0(".yaml") |>
+        normalizePath(mustWork = FALSE)
 
     if (!dir.exists(dataset_dir)) {
         dir.create(dataset_dir)
@@ -176,9 +174,11 @@ write_milestones_to_dataset <- function(
         }
     }
 
-    yaml::write_yaml(
-        x = milestones,
-        file = output_path
+    milestones_yaml <- yaml::as.yaml(milestones)
+    writeLines(
+        text = enc2utf8(milestones_yaml),
+        con = output_path,
+        useBytes = TRUE
     )
     return(invisible(TRUE))
 }
