@@ -7,7 +7,8 @@
 #' the issue is still open or \code{"closed"} if the issue is now closed.
 #' @param body a string. The body (text) of the issue.
 #' @param number a string. The number of the issue.
-#' @param created_at a date (or timestamp). The title of the issue.
+#' @param created_at a date (or timestamp). The creation date of the issue.
+#' @param closed_at a date (or timestamp). The closing date of the issue.
 #' @param labels a vector string (or missing). The labels of the issue.
 #' @param milestone a string (or missing). The milestone of the issue.
 #' @inheritParams get_issues
@@ -17,7 +18,7 @@
 #' @param creator a string. The GitHub username of the creator of the issue.
 #' @param assignee a string. The GitHub username of the assignee of the issue.
 #' @param state_reason a string. \code{"open"}, \code{"completed"},
-#' \code{"reopened"} or \code{"not_planned"}.
+#' \code{"reopened"}, \code{"not_planned"} or \code{"duplicated"}.
 #' @param \dots Other information we would like to add to the issue.
 #'
 #' @returns a \code{IssueTB} object.
@@ -88,11 +89,12 @@ new_issue.IssuesTB <- function(x, ...) {
 #' @export
 new_issue.default <- function(
     x,
-    title,
-    body,
-    number,
-    state = c("open", "closed"),
+    title = NA_character_,
+    body = NA_character_,
+    number = NA_integer_,
+    state = NA_character_,
     created_at = Sys.Date(),
+    closed_at = as.Date(NA_integer_),
     labels = NULL,
     milestone = NA_character_,
     repo = NA_character_,
@@ -105,26 +107,6 @@ new_issue.default <- function(
     state_reason = NA_character_,
     ...
 ) {
-    state <- match.arg(state)
-
-    if (missing(title) && missing(body) && missing(number)) {
-        title <- character(0L)
-        body <- character(0L)
-        number <- integer(0L)
-        state <- character(0L)
-        created_at <- format_timestamp(as.Date(character(0L)))
-        labels <- list()
-        milestone <- character(0L)
-        repo <- character(0L)
-        owner <- character(0L)
-        url <- character(0L)
-        html_url <- character(0L)
-        comments <- list()
-        creator <- character(0L)
-        assignee <- character(0L)
-        state_reason <- character(0L)
-    }
-
     issue <- list(
         number = as.integer(number),
         title = title,
@@ -134,6 +116,7 @@ new_issue.default <- function(
         html_url = html_url,
         milestone = milestone,
         created_at = format_timestamp(created_at),
+        closed_at = format_timestamp(closed_at),
         creator = creator,
         assignee = assignee,
         state_reason = state_reason,
@@ -156,7 +139,9 @@ new_issue.default <- function(
 #' the issues are still open or \code{"closed"} if the issues are now closed.
 #' @param body a vector of string. The bodies (text) of the issues.
 #' @param number a vector of string. The numbers of the issues.
-#' @param created_at a vector of date (or timestamp). The creation dates of the
+#' @param created_at a vector of date (or timestamp). The creation date of the
+#' issues.
+#' @param closed_at a vector of date (or timestamp). The closing date of the
 #' issues.
 #' @param labels a list of vector string (or missing). The labels of the issues.
 #' @param milestone a vector of string (or missing). The milestones of the
@@ -170,7 +155,7 @@ new_issue.default <- function(
 #' @param assignee a vector of string. The GitHub usernames of the assignee of
 #' the issues.
 #' @param state_reason a vector of string. \code{"open"}, \code{"completed"},
-#' \code{"reopened"} or \code{"not_planned"}.
+#' \code{"reopened"}, \code{"not_planned"} or \code{"duplicated"}.
 #' @param \dots Other information we would like to add to the issue.
 #'
 #' @returns a \code{IssuesTB} object.
@@ -261,6 +246,7 @@ new_issues.default <- function(
     number,
     state,
     created_at = Sys.Date(),
+    closed_at = as.Date(NA_integer_),
     labels = list(),
     comments = list(),
     milestone = NA_character_,
@@ -279,6 +265,7 @@ new_issues.default <- function(
         number <- integer(0L)
         state <- character(0L)
         created_at <- format_timestamp(as.Date(character(0L)))
+        closed_at <- format_timestamp(as.Date(character(0L)))
         milestone <- character(0L)
         repo <- character(0L)
         owner <- character(0L)
@@ -291,7 +278,11 @@ new_issues.default <- function(
 
     if (missing(labels)) {
         labels <- rep(
-            x = list(list()),
+            x = list(data.frame(
+                name = character(0L),
+                color = character(0L),
+                stringsAsFactors = FALSE
+            )),
             times = length(title)
         )
     }
@@ -315,6 +306,7 @@ new_issues.default <- function(
         html_url = html_url,
         milestone = milestone,
         created_at = format_timestamp(created_at),
+        closed_at = format_timestamp(closed_at),
         creator = creator,
         assignee = assignee,
         state_reason = state_reason,
@@ -333,8 +325,20 @@ new_issues.default <- function(
 #' @exportS3Method `[` IssuesTB
 #' @method `[` IssuesTB
 #' @export
-`[.IssuesTB` <- function(x, i, j, ..., drop = TRUE) {
-    output <- new_issues(NextMethod())
+`[.IssuesTB` <- function(x, i, j, drop = TRUE) {
+    output <- NextMethod("[")
+    Narg <- nargs() - !missing(drop)
+    # Cas sélection de colonne
+    if (!missing(j)) {
+        if (length(j) > 1L || !drop) {
+            return(as.data.frame(output))
+        }
+        return(output)
+    } else if (Narg == 2L && !missing(i)) {
+        return(as.data.frame(output))
+    }
+
+    output <- new_issues(output)
     if (drop && nrow(output) == 1L) {
         return(new_issue(output))
     }
@@ -419,6 +423,14 @@ rbind.IssuesTB <- function(...) {
         new_issues()
 }
 
+#' @exportS3Method subset IssuesTB
+#' @method subset IssuesTB
+#' @export
+subset.IssuesTB <- function(x, ...) {
+    output <- new_issues(NextMethod())
+    return(output)
+}
+
 #' @rdname sample
 #' @export
 #' @inherit base::sample
